#ifndef locale_charset
#define locale_charset() ("")
#endif
